from setuptools import setup

setup(name='dsdaba_distributions',
      version='0.11',
      description='Gaussian and Binomial distributions',
      packages=['dsdaba_distributions'],
      author='Yuchen Xie',
      author_email='xie.yuc@husky.neu.edu',
      zip_safe=False)
